Officially Released Appellate Court Opinions
Keywords: Connecticut, Judicial, Civil, Opinion, Criminal, Law Libraries, Juror, Jury, Victim, Small Claims, Justice, Supreme, Trial, Appellate, Court, Judical, Attorney, Judge, Court, docket, Housing, Landlord, Grievance, Bar Exam, Legal, Probate, Superior, Magistrate, Marshal

Archive of Appellate Court Opinions 2015 Previous Years
To Search: Hit Control, F, on your keyboard, and enter the name.
Information on how to purchase the Connecticut Law Journal or the Connecticut Appellate Reports
Quick Links
Advance Release Opinions
Appellate Court Archive
Memorandum Archive
Supreme Court Archive
To be Published in Connecticut Law Journal of 6/23/2015: AC37294 - In re Payton V. AC37294 - In re Maddy V. AC36194 - J. Wm. Foley, Inc. v. United Illuminating Co. AC36075 - Briere v. Greater Hartford Orthopedic Group, P.C. AC36462 - U.S. Bank National Assn. v. Sorrentino AC36461 - Charles v. Mitchell AC36917 - Portfolio Recovery Associates, LLC v. Healy AC35986 - State v. Edwards AC37163 - State v. Roberts Published in Connecticut Law Journal of 6/16/2015: AC37701 - In re G. Q. AC35800 - State v. Kallberg AC36411 - SBD Kitchens, LLC v. Jefferson AC36412, AC36613 - Jefferson v. SBD Kitchens, LLC AC36244 - State v. Schuler AC36444, AC36555 - Modaffari v. Greenwich Hospital AC36373 - Wagner v. Our Lady of Mount Caritas, O.S.B., Inc. AC36501 - Procaccini v. Procaccini AC36591 - Nassra v. Nassra AC36628 - Civie v. Connecticut Siting Council AC36692 - In re Angel R. AC36141 - McGee v. Commissioner of Correction AC36190 - Browne v. Commissioner of Correction Published in Connecticut Law Journal of 6/9/2015: AC36516 - Ogden v. Zoning Board of Appeals AC36436 - Peruta v. Freedom of Information Commission AC36003 - Diaz v. Commissioner of Correction AC36619 - Townsend v. Sterling Published in Connecticut Law Journal of 6/2/2015: AC36845 - In re Oreoluwa O. AC36623 - McCants v. State Farm Fire & Casualty Co. AC36265 - Beeman v. Stratford AC36181 - State v. Young AC36086 - McLoughlin v. McLoughlin AC36604 - Sousa v. Sousa AC36920 - Stewart v. Stewart AC36886 - Rozbicki v. Statewide Grievance Committee AC36385 - Ribeiro v. Fasano, Ippolito & Lee, P.C. AC36385 Dissent - Ribeiro v. Fasano, Ippolito & Lee, P.C. Published in Connecticut Law Journal of 5/26/2015: AC36508 - State v. Sherrod AC36463 - Lukas v. McCoy AC35836 - State v. Jose V. AC35575 - Webster Bank, N.A. v. GFI Groton, LLC AC36798 - State v. Pace AC36279 - Tate v. Safeco Ins. Co. of Illinois AC35567 - State v. Tilus AC36363 - LoRicco v. Hula’s New Haven, LLC Published in Connecticut Law Journal of 5/19/2015: AC36441 - Zuvic, Carr & Associates, Inc. v. Morande Brothers, Inc. AC35896 - Tomick v. United Parcel Service, Inc. AC36379 - Phillips v. Administrator, Unemployment Compensation Act AC36523 - Ferraiolo v. Ferraiolo AC33316 - Hylton v. Gunter AC36729 - Kloth-Zanard v. Dept. of Social Services AC35681 - Namhard v. Commissioner of Correction Published in Connecticut Law Journal of 5/12/2015: AC35584 - American Home Mortgage Servicing, Inc. v. Reilly AC35503 - Coppola Construction Co. v. Hoffman Enterprises Ltd. Partnership AC36431 - Champeau v. Blitzer AC35726 - Leftridge v. Wiggins AC35335 - Welsh v. Martinez AC36161 - Mahon v. Commissioner of Correction AC36744 - Saunders v. Commissioner of Correction AC36149 - Roger B. v. Commissioner of Correction AC36706 - State v. Christensen Published in Connecticut Law Journal of 5/5/2015: AC36409 - CHFA–Small Properties, Inc. v. Elazazy AC35882 - First American Title Ins. Co. v. 273 Water Street, LLC AC36207 - Youngman v. Schiavone AC36207 Dissent - Youngman v. Schiavone AC34936, A36617 - Callahan v. Callahan AC35996 - State v. Vaught AC36150 - Boyd v. Commissioner of Correction Published in Connecticut Law Journal of 4/28/2015: AC36429 - Fulton v. Fulton AC35988 - Milford Paintball, LLC v. Wampus Milford Associates, LLC AC36065 - Rheaume v. Rheaume AC35485 - Spears v. Elder AC35045 - State v. Tenay AC36564 - Barbee v. Sysco Connecticut, LLC AC36328 - McMorris v. New Haven Police Dept. AC36311 - Cheshire Land Trust, LLC v. Casey AC36351 - Greene v. Keating Published in Connecticut Law Journal of 4/21/15: AC36342 - Budrawich v. Budrawich AC36087 - State v. Badaracco AC36419 - Customers Bank v. CB Associates, Inc. AC36325 - Izikson v. Protein Science Corp. AC36211 - Vanghele v. Fairfield AC36547 - Abendroth v. Moffo Published in Connecticut Law Journal of 4/14/15: AC35807 - Llera v. Commissioner of Correction AC36240 - Customers Bank v. Tomonto Industries, LLC AC36058 - Birkhamshaw v. Socha AC36714 - O’Rourke v. Commissioner of Motor Vehicles AC32803 - State v. Smith AC36673 - Perry v. Perry AC36046 - Eaddy v. Bridgeport AC34862 - State v. Kirby Published in Connecticut Law Journal of 4/7/15: AC34886 - State v. Bush AC35418 - State v. LaFleur AC36275 - North Star Contracting Corp. v. Albright AC36175 - Ruiz v. Commissioner of Correction AC35682 - Madigan v. Housing Authority AC35682 Concurrence - Madigan v. Housing Authority AC36635 - O, R & L Commercial, LLC v. Colt Gateway, LLC AC36241 - Barbour v. Barbour AC36120 - Mitchell v. Commissioner of Correction Published in Connecticut Law Journal of 3/31/15: AC35605 - State v. Davis AC36446 - Gorski v. McIsaac AC36202 - Moody v. Commissioner of Correction AC36655 - Solway v. Ray AC36368 - Martocchio v. Savoir AC36114 - Emerick v. Freedom of Information Commission AC36493 - Commission on Human Rights & Opportunities v. Echo Hose Ambulance AC35721 - State v. Negedu Published in Connecticut Law Journal of 3/24/15: AC35917 - AFSCME, AFL-CIO, Council 4, Local 2405 v. Norwalk AC36561 - Chase Home Finance, LLC v. Morneau AC36102 - Sargent v. Sargent AC35601 - Congress Street Condominium Association, Inc. v. Anderson AC36330 - Bozelko v. Papastavros AC34910 - State v. A. M. AC35712 - Bellini v. Patterson Oil Co. AC35727, AC36201, AC36378 - Damato v. Commissioner of Correction Published in Connecticut Law Journal of 3/17/15: AC36353 - Havis-Carbone v. Carbone AC35720 - State v. Houghtaling AC36684, AC36685, AC36686 - State v. Corringham AC36474 - Wells Fargo Bank, N.A. v. Treglia AC36356 - Sharp Electronics Corp. v. Solaire Development, LLC AC36540 - Deutsche Bank National Trust Co. v. McKeith AC36875 - Norwich v. Norwich Harborview Corp. AC35905 - Light v. Grimes AC35733 - Yerinides v. Commissioner of Correction Published in Connecticut Law Journal of 3/10/15: AC35848 - Sellers v. Sellers Garage, Inc. AC36420 - State v. Cruz AC36196 - Verrillo v. Zoning Board of Appeals AC35878 - Conee v. Dept. of Social Services AC35471 - Saggese v. Beazley Co. Realtors AC34577 - State v. Nowacki AC36059 - State v. Gemmell AC36647 - Harnage v. Torres Published in Connecticut Law Journal of 3/3/15: AC35947 - State v. Book AC36037 - State v. Washington AC36421 - Gagliardi v. Commissioner of Children & Families AC37041 - In re Alexandria Published in Connecticut Law Journal of 2/24/15: AC35406 - Rodriguez v. State AC35570 - Tremper v. State AC35972 - Bouchard v. Deep River AC36021 - State v. Nicholson AC34625, AC34838 - Nelson v. Tradewind Aviation, LLC AC35407 - Andrews v. Commissioner of Correction AC36354 - State v. Walczyk Published in Connecticut Law Journal of 2/17/15: AC35758 - State v. Gould AC35758 Concurrence - State v. Gould AC34078, AC34710, AC35204 - McKeon v. Lennon AC36198 - Housing Development Fund, Inc. v. Burke Real Estate Management, LLC Published in Connecticut Law Journal of 2/10/15: AC35476 - Salzbrunn v. Salzbrunn AC35476 Dissent - Salzbrunn v. Salzbrunn AC35580 - State v. Giovanni P. AC35976 - Wilson v. Maefair Health Care Centers AC35122 - Roberts v. Commissioner of Correction AC36267 - Rozbicki v. Gisselbrecht AC35778 - Kowalyshyn v. Commissioner of Correction Published in Connecticut Law Journal of 2/3/15: AC35904 - Stratford v. International Federation of Professional & Technical Engineers, Local 134 AC36335 - Davis v. Administrator, Unemployment Compensation Act AC35954 - Nxegen, LLC v. Carbone AC36339 - McGuinness v. McGuinness AC35889 - Wilkes v. Thomson AC35607 - McEntyre v. Commissioner of Correction AC36324 - National City Real Estate Services, LLC v. Tuttle AC35945 - Cimino v. Cimino Published in Connecticut Law Journal of 1/27/15: AC35433 - Bellsite Development, LLC v. Monroe AC35691 - Paulino v. Commissioner of Correction AC33424 - St. Juste v. Commissioner of Correction AC36041 - Dept. of Transportation v. Cheriha, LLC AC35426 - State v. Fairchild AC36451 - State v. Williamson AC33223 - Martin v. Commissioner of Correction AC36039 - Talton v. Commissioner of Correction Published in Connecticut Law Journal of 1/20/15: AC36852 - In re Santiago G. AC36530 - Ciottone v. Ciottone AC34715 - State v. James E. AC35006 - State v. Bullock AC35304 - Brown v. Bridgeport Police Dept. AC35547 - State v. Derks AC36258 - Tyson v. Commissioner of Correction AC34556 - State v. Dakers AC36410 - State v. Stiggle Published in Connecticut Law Journal of 1/13/15: AC35533 - State v. Ayala AC32247, AC32830 - Gagne v. Vaccaro AC35497 - Millan v. Commissioner of Correction AC35849 - Previti v. Monro Muffler Brake, Inc. AC35133 - Taylor v. Commissioner of Correction AC34491 - State v. McNeil AC35450 - State v. Bozelko AC36016 - Oldani v. Oldani Published in Connecticut Law Journal of 1/06/15: AC35244 - State v. Barone AC35953 - Bligh v. Travelers Home & Marine Ins. Co. AC36165 - State v. Stephenson AC35378 - Lawrence v. Weiner AC35883 - Banziruk v. Banziruk AC34989 - Johnson v. Commissioner of Correction AC36340 - State v. Dotson AC35789 - Collazo v. Commissioner of Correction
[../include.htm]